"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from nuaudit_python_autogen.api_client import ApiClient, Endpoint as _Endpoint
from nuaudit_python_autogen.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from nuaudit_python_autogen.model.error_message import ErrorMessage
from nuaudit_python_autogen.model.http_validation_error import HTTPValidationError
from nuaudit_python_autogen.model.organization import Organization
from nuaudit_python_autogen.model.organization_mutation import OrganizationMutation


class OrganizationsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.create_organization_endpoint = _Endpoint(
            settings={
                'response_type': (Organization,),
                'auth': [
                    'APIKeyHeader'
                ],
                'endpoint_path': '/organizations',
                'operation_id': 'create_organization',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'organization_mutation',
                ],
                'required': [
                    'organization_mutation',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'organization_mutation':
                        (OrganizationMutation,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'organization_mutation': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.delete_organization_endpoint = _Endpoint(
            settings={
                'response_type': (Organization,),
                'auth': [
                    'APIKeyHeader'
                ],
                'endpoint_path': '/organizations/{organization_id}',
                'operation_id': 'delete_organization',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'organization_id',
                ],
                'required': [
                    'organization_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'organization_id':
                        (str,),
                },
                'attribute_map': {
                    'organization_id': 'organization_id',
                },
                'location_map': {
                    'organization_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.list_organizations_endpoint = _Endpoint(
            settings={
                'response_type': ([Organization],),
                'auth': [
                    'APIKeyHeader'
                ],
                'endpoint_path': '/organizations',
                'operation_id': 'list_organizations',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def create_organization(
        self,
        organization_mutation,
        **kwargs
    ):
        """Create Organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_organization(organization_mutation, async_req=True)
        >>> result = thread.get()

        Args:
            organization_mutation (OrganizationMutation):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Organization
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['organization_mutation'] = \
            organization_mutation
        return self.create_organization_endpoint.call_with_http_info(**kwargs)

    def delete_organization(
        self,
        organization_id,
        **kwargs
    ):
        """Delete Organization  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_organization(organization_id, async_req=True)
        >>> result = thread.get()

        Args:
            organization_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Organization
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['organization_id'] = \
            organization_id
        return self.delete_organization_endpoint.call_with_http_info(**kwargs)

    def list_organizations(
        self,
        **kwargs
    ):
        """List Organizations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_organizations(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [Organization]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.list_organizations_endpoint.call_with_http_info(**kwargs)




"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.organizations_api import OrganizationsApi  # noqa: E501


class TestOrganizationsApi(unittest.TestCase):
    """OrganizationsApi unit test stubs"""

    def setUp(self):
        self.api = OrganizationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_organization(self):
        """Test case for create_organization

        Create Organization  # noqa: E501
        """
        pass

    def test_delete_organization(self):
        """Test case for delete_organization

        Delete Organization  # noqa: E501
        """
        pass

    def test_list_organizations(self):
        """Test case for list_organizations

        List Organizations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from nuaudit_python_autogen.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from nuaudit_python_autogen.model.api_client import APIClient
from nuaudit_python_autogen.model.api_client_mutation import APIClientMutation
from nuaudit_python_autogen.model.api_key import APIKey
from nuaudit_python_autogen.model.api_key_mutation import APIKeyMutation
from nuaudit_python_autogen.model.accept_invite_mutation import AcceptInviteMutation
from nuaudit_python_autogen.model.actor import Actor
from nuaudit_python_autogen.model.actor_record import ActorRecord
from nuaudit_python_autogen.model.actor_record_mutation import ActorRecordMutation
from nuaudit_python_autogen.model.billing import Billing
from nuaudit_python_autogen.model.billing_mutation import BillingMutation
from nuaudit_python_autogen.model.error_message import ErrorMessage
from nuaudit_python_autogen.model.http_validation_error import HTTPValidationError
from nuaudit_python_autogen.model.indexes import Indexes
from nuaudit_python_autogen.model.invite import Invite
from nuaudit_python_autogen.model.invite_mutation import InviteMutation
from nuaudit_python_autogen.model.invite_status import InviteStatus
from nuaudit_python_autogen.model.metadata import Metadata
from nuaudit_python_autogen.model.organization import Organization
from nuaudit_python_autogen.model.organization_mutation import OrganizationMutation
from nuaudit_python_autogen.model.payment_method import PaymentMethod
from nuaudit_python_autogen.model.permission import Permission
from nuaudit_python_autogen.model.permission_deletion import PermissionDeletion
from nuaudit_python_autogen.model.permission_mutation import PermissionMutation
from nuaudit_python_autogen.model.record import Record
from nuaudit_python_autogen.model.record_mutation import RecordMutation
from nuaudit_python_autogen.model.resource import Resource
from nuaudit_python_autogen.model.resource_record import ResourceRecord
from nuaudit_python_autogen.model.resource_record_mutation import ResourceRecordMutation
from nuaudit_python_autogen.model.role import Role
from nuaudit_python_autogen.model.role_mutation import RoleMutation
from nuaudit_python_autogen.model.scope import Scope
from nuaudit_python_autogen.model.settings import Settings
from nuaudit_python_autogen.model.settings_mutation import SettingsMutation
from nuaudit_python_autogen.model.trail import Trail
from nuaudit_python_autogen.model.trail_mutation import TrailMutation
from nuaudit_python_autogen.model.usage import Usage
from nuaudit_python_autogen.model.user import User
from nuaudit_python_autogen.model.validation_error import ValidationError



"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.trails_api import TrailsApi  # noqa: E501


class TestTrailsApi(unittest.TestCase):
    """TrailsApi unit test stubs"""

    def setUp(self):
        self.api = TrailsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_trail(self):
        """Test case for create_trail

        Create Trail  # noqa: E501
        """
        pass

    def test_delete_trail(self):
        """Test case for delete_trail

        Delete Trail  # noqa: E501
        """
        pass

    def test_get_trail(self):
        """Test case for get_trail

        Get Trail  # noqa: E501
        """
        pass

    def test_list_trails(self):
        """Test case for list_trails

        List Trails  # noqa: E501
        """
        pass

    def test_update_trail(self):
        """Test case for update_trail

        Update Trail  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.roles_api import RolesApi  # noqa: E501


class TestRolesApi(unittest.TestCase):
    """RolesApi unit test stubs"""

    def setUp(self):
        self.api = RolesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_api_client_to_role(self):
        """Test case for add_api_client_to_role

        Add Api Client To Role  # noqa: E501
        """
        pass

    def test_add_user_to_role(self):
        """Test case for add_user_to_role

        Add User To Role  # noqa: E501
        """
        pass

    def test_create_role(self):
        """Test case for create_role

        Create Role  # noqa: E501
        """
        pass

    def test_delete_role(self):
        """Test case for delete_role

        Delete Role  # noqa: E501
        """
        pass

    def test_get_role(self):
        """Test case for get_role

        Get Role  # noqa: E501
        """
        pass

    def test_list_api_clients_for_role(self):
        """Test case for list_api_clients_for_role

        List Api Clients For Role  # noqa: E501
        """
        pass

    def test_list_roles(self):
        """Test case for list_roles

        List Roles  # noqa: E501
        """
        pass

    def test_list_users_for_role(self):
        """Test case for list_users_for_role

        List Users For Role  # noqa: E501
        """
        pass

    def test_remove_api_client_from_role(self):
        """Test case for remove_api_client_from_role

        Remove Api Client From Role  # noqa: E501
        """
        pass

    def test_remove_user_from_role(self):
        """Test case for remove_user_from_role

        Remove User From Role  # noqa: E501
        """
        pass

    def test_update_role(self):
        """Test case for update_role

        Update Role  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.model.actor_record_mutation import ActorRecordMutation


class TestActorRecordMutation(unittest.TestCase):
    """ActorRecordMutation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testActorRecordMutation(self):
        """Test ActorRecordMutation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ActorRecordMutation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.api_clients_api import APIClientsApi  # noqa: E501


class TestAPIClientsApi(unittest.TestCase):
    """APIClientsApi unit test stubs"""

    def setUp(self):
        self.api = APIClientsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_api_client(self):
        """Test case for create_api_client

        Create Api Client  # noqa: E501
        """
        pass

    def test_delete_api_client(self):
        """Test case for delete_api_client

        Delete Api Client  # noqa: E501
        """
        pass

    def test_get_api_client(self):
        """Test case for get_api_client

        Get Api Client  # noqa: E501
        """
        pass

    def test_list_api_clients(self):
        """Test case for list_api_clients

        List Api Clients  # noqa: E501
        """
        pass

    def test_list_roles_for_api_client(self):
        """Test case for list_roles_for_api_client

        List Roles For Api Client  # noqa: E501
        """
        pass

    def test_update_api_client(self):
        """Test case for update_api_client

        Update Api Client  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.19.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.invites_api import InvitesApi  # noqa: E501


class TestInvitesApi(unittest.TestCase):
    """InvitesApi unit test stubs"""

    def setUp(self):
        self.api = InvitesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accept_invite(self):
        """Test case for accept_invite

        Accept Invite  # noqa: E501
        """
        pass

    def test_create_invite(self):
        """Test case for create_invite

        Create Invite  # noqa: E501
        """
        pass

    def test_delete_invite(self):
        """Test case for delete_invite

        Delete Invite  # noqa: E501
        """
        pass

    def test_list_invites(self):
        """Test case for list_invites

        List Invites  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
